@@ -1,4 +1,5 @@
 import json
+import logging
 from typing import Dict
 
 import pytest
@@ -174,7 +175,7 @@ def test_metric_result_dict_access():
     assert metric.get("invalid_key", "default_val") == "default_val"
 
     # keys()
-    assert set(metric.keys()) == {"score", "reason", "is_score_valid"}
+    assert set(metric.keys()) == {"score", "reason", "is_score_valid", "data"}
 
     # values() - order might not be guaranteed by model_fields, so check content
     # Pydantic model_fields preserves declaration order.
@@ -660,3 +661,63 @@ def test_stable_hash_across_subprocess():
 
     assert isinstance(child_hash, int)
     assert parent_hash == child_hash
+
+
+def test_evaluation_row_extra_fields():
+    example = {
+        "messages": [
+            {"role": "user", "content": "What is the capital of France?"},
+            {"role": "assistant", "content": "The capital of France is Paris."},
+        ],
+        "ground_truth": "Paris",
+        "evaluation_result": {"score": 1.0, "reason": "Correct"},
+        "input_metadata": {"model": "gpt-4"},
+        "eval": {"score": 0.5},
+        "eval_details": {
+            "score": 0.5,
+            "reason": "Correct",
+            "is_score_valid": True,
+            "metrics": {
+                "accuracy": {
+                    "score": 1.0,
+                    "reason": "Correct",
+                    "is_score_valid": True,
+                },
+            },
+        },
+        "extra_fields": {
+            "test": "test",
+        },
+    }
+    row = EvaluationRow(**example)
+    dictionary = json.loads(row.model_dump_json())
+    assert "eval" in dictionary
+    assert "accuracy" in dictionary["eval_details"]["metrics"]
+    assert "test" in dictionary["extra_fields"]
+
+
+def test_message_with_weight_dump():
+    example = {
+        "role": "user",
+        "content": "Hello, how are you?",
+        "weight": 0,
+    }
+
+    message = Message(**example)
+    dictionary = message.model_dump()
+    assert "weight" in dictionary
+    assert dictionary["weight"] == 0
+
+
+def test_message_dump_for_chat_completion_request():
+    example = {
+        "role": "user",
+        "content": "Hello, how are you?",
+        "weight": 0,
+        "reasoning_content": "I am thinking about the user's question",
+    }
+    message = Message(**example)
+    dictionary = message.dump_mdoel_for_chat_completion_request()
+    assert "weight" not in dictionary
+    assert "reasoning_content" not in dictionary
+    assert dictionary["content"] == "Hello, how are you?"
